@@ -1,5 +1,5 @@
 /* GNOME-DB Components
- * Copyright (C) 2000 - 2005 The GNOME Foundation.
+ * Copyright (C) 2000 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -20,6 +20,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <glib/gi18n-lib.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtknotebook.h>
@@ -221,16 +222,16 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 		case BROWSE_BUTTON:
 		{
 			char *argv[3];
-			gboolean result;
+			gboolean sresult;
 			
 			/* run gnome-database-properties dictig tool */
 			argv[0] = (char *) "gnome-db-browser";
 			argv[1] = (char *) dsn;
 			argv[2] = NULL;
 			
-			result = g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+			sresult = g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 						NULL, NULL, NULL, NULL);
-			if (!result) {
+			if (!sresult) {
 				GtkWidget *msgdialog;
 				str = g_strdup_printf ("<b>%s</b>", _("Could not execute browser program (gnome-db-browser)."));
 				msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog), GTK_DIALOG_MODAL,
@@ -239,6 +240,8 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 				gtk_dialog_run (GTK_DIALOG (msgdialog));
 				gtk_widget_destroy (msgdialog);
 			}
+			else
+				result = GTK_RESPONSE_OK; /* force closing of this dialog */
 		}
 		break;
 		default:
