@@ -22,7 +22,6 @@
 
 #include <string.h>
 #include <libgnomedb/libgnomedb.h>
-#include <libgnomedb/gnome-db-window.h>
 #include <glade/glade-init.h>
 #include <glade/glade-build.h>
 
@@ -43,29 +42,6 @@ gnomedb_dialog_find_internal_child (GladeXML *xml,
 	return NULL;
 }
 
-static GtkWidget *
-gnomedb_window_find_internal_child (GladeXML    *xml,
-				    GtkWidget   *parent,
-				    const gchar *childname)
-{
-        if (!strcmp (childname, "vbox")) {
-                GtkWidget *ret;
-
-                if ((ret = bonobo_window_get_contents (BONOBO_WINDOW (parent))))
-                        return ret;
-                else {
-                        GtkWidget *box;
-
-                        box = gtk_vbox_new (FALSE, 0);
-                        bonobo_window_set_contents (BONOBO_WINDOW (parent), box);
-
-                        return box;
-                }
-        }
-
-	return NULL;
-}
-
 /* this macro puts a version check function into the module */
 GLADE_MODULE_CHECK_INIT
 
@@ -75,18 +51,12 @@ glade_module_register_widgets (void)
 	glade_require ("gtk");
 	glade_require ("gnome");
 
-	glade_register_widget (GNOME_DB_TYPE_BROWSER,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_COMBO,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_CONNECTION_PROPERTIES,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_CONNECTION_SELECTOR,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_DATA_SOURCE_SELECTOR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
@@ -105,6 +75,9 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_ERROR_DIALOG,
 			       NULL, glade_standard_build_children,
 			       gnomedb_dialog_find_internal_child);
+	glade_register_widget (GNOME_DB_TYPE_FIND_DIALOG,
+			       NULL, glade_standard_build_children,
+			       gnomedb_dialog_find_internal_child);
 	glade_register_widget (GNOME_DB_TYPE_FORM,
 			       glade_standard_build_widget,
 			       NULL, NULL);
@@ -114,12 +87,6 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_GRID,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_ICON_LIST,
-			       glade_standard_build_widget,
-			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_LIST,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_LOGIN,
 			       glade_standard_build_widget,
 			       NULL, NULL);
@@ -129,9 +96,6 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_PROVIDER_SELECTOR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_TABLE_EDITOR,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 
 	glade_provide ("gnomedb");
 }
