@@ -1,6 +1,6 @@
 /* gnome-db-data-entry.c
  *
- * Copyright (C) 2003 - 2005 Vivien Malerba
+ * Copyright (C) 2003 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -111,10 +111,10 @@ gnome_db_data_entry_iface_init (gpointer g_class)
  * the widget can handle.
  */
 void
-gnome_db_data_entry_set_value_type (GnomeDbDataEntry *de, GdaValueType type)
+gnome_db_data_entry_set_value_type (GnomeDbDataEntry *de, GType type)
 {
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
-	g_return_if_fail (type != GDA_VALUE_TYPE_UNKNOWN);
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
+	g_return_if_fail (type != G_TYPE_INVALID);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value_type)
 		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value_type) (de, type);
@@ -127,16 +127,16 @@ gnome_db_data_entry_set_value_type (GnomeDbDataEntry *de, GdaValueType type)
  *
  * Fetch the type of data the GnomeDbDataEntry handles
  *
- * Returns: the GdaValueType type
+ * Returns: the GType type
  */
-GdaValueType
+GType
 gnome_db_data_entry_get_value_type (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), GDA_VALUE_TYPE_UNKNOWN);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), G_TYPE_INVALID);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value_type)
 		return (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value_type) (de);
-	return GDA_VALUE_TYPE_UNKNOWN;
+	return G_TYPE_INVALID;
 }
 
 
@@ -146,13 +146,13 @@ gnome_db_data_entry_get_value_type (GnomeDbDataEntry *de)
  * @value: 
  *
  * Push a value into the GnomeDbDataEntry. The value parameter must either be:
- * - NULL or of type GDA_VALUE_TYPE_NULL, or
+ * - NULL or of type GDA_TYPE_NULL, or
  * - of type specified using gnome_db_data_entry_set_value_type.
  */
 void
-gnome_db_data_entry_set_value (GnomeDbDataEntry *de, const GdaValue * value)
+gnome_db_data_entry_set_value (GnomeDbDataEntry *de, const GValue * value)
 {
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value)
 		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value) (de, value);
@@ -163,16 +163,16 @@ gnome_db_data_entry_set_value (GnomeDbDataEntry *de, const GdaValue * value)
  * @de: a #GtkWidget object which implements the #GnomeDbDataEntry interface
  *
  * Fetch the value held in the GnomeDbDataEntry widget. If the value is set to NULL,
- * the returned value is of type GDA_VALUE_TYPE_NULL. If the value is set to default,
- * then the returned value is of type GDA_VALUE_TYPE_NULL or is the default value if it
+ * the returned value is of type GDA_TYPE_NULL. If the value is set to default,
+ * then the returned value is of type GDA_TYPE_NULL or is the default value if it
  * has been provided to the widget (and is of the same type as the one provided by @de).
  *
- * Returns: a new GdaValue
+ * Returns: a new GValue
  */
-GdaValue *
+GValue *
 gnome_db_data_entry_get_value (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), NULL);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), NULL);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value)
 		return (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value) (de);
@@ -190,9 +190,9 @@ gnome_db_data_entry_get_value (GnomeDbDataEntry *de)
  * also sets this value as the original value.
  */
 void
-gnome_db_data_entry_set_value_orig (GnomeDbDataEntry *de, const GdaValue *value)
+gnome_db_data_entry_set_value_orig (GnomeDbDataEntry *de, const GValue *value)
 {
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value_orig)
 		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value_orig) (de, value);
@@ -207,8 +207,8 @@ gnome_db_data_entry_set_value_orig (GnomeDbDataEntry *de, const GdaValue *value)
 void
 gnome_db_data_entry_set_current_as_orig (GnomeDbDataEntry *de)
 {
-	GdaValue *value;
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
+	GValue *value;
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
 	
 	value = gnome_db_data_entry_get_value (de);
 	gnome_db_data_entry_set_value_orig (de, value);
@@ -223,12 +223,12 @@ gnome_db_data_entry_set_current_as_orig (GnomeDbDataEntry *de)
  *
  * Fetch the original value held in the GnomeDbDataEntry widget
  *
- * Returns: the GdaValue
+ * Returns: the GValue
  */
-const GdaValue *
+const GValue *
 gnome_db_data_entry_get_value_orig (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), NULL);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), NULL);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value_orig)
 		return (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_value_orig) (de);
@@ -243,15 +243,15 @@ gnome_db_data_entry_get_value_orig (GnomeDbDataEntry *de)
  * @value: 
  *
  * Sets the default value for the GnomeDbDataEntry which gets displayed when the
- * user forces the default value. If it is not set then it is set to type GDA_VALUE_TYPE_NULL.
+ * user forces the default value. If it is not set then it is set to type GDA_TYPE_NULL.
  * The value parameter must either be:
- * - NULL or of type GDA_VALUE_TYPE_NULL, or
+ * - NULL or of type GDA_TYPE_NULL, or
  * - of type specified using gnome_db_data_entry_set_value_type.
  */
 void
-gnome_db_data_entry_set_value_default (GnomeDbDataEntry *de, const GdaValue *value)
+gnome_db_data_entry_set_value_default (GnomeDbDataEntry *de, const GValue *value)
 {
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
 	g_return_if_fail (value);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_value_default)
@@ -270,7 +270,7 @@ gnome_db_data_entry_set_value_default (GnomeDbDataEntry *de, const GdaValue *val
 void
 gnome_db_data_entry_set_attributes (GnomeDbDataEntry *de, guint attrs, guint mask)
 {
-	g_return_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de));
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_attributes)
 		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_attributes) (de, attrs, mask);
@@ -287,7 +287,7 @@ gnome_db_data_entry_set_attributes (GnomeDbDataEntry *de, guint attrs, guint mas
 guint
 gnome_db_data_entry_get_attributes (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), 0);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), 0);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_attributes)
 		return (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_attributes) (de);
@@ -307,7 +307,7 @@ gnome_db_data_entry_get_attributes (GnomeDbDataEntry *de)
 GdaDataHandler  *
 gnome_db_data_entry_get_handler (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), NULL);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), NULL);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_handler)
 		return (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->get_handler) (de);
@@ -326,7 +326,7 @@ gnome_db_data_entry_get_handler (GnomeDbDataEntry *de)
 gboolean
 gnome_db_data_entry_expand_in_layout (GnomeDbDataEntry *de)
 {
-	g_return_val_if_fail (de && IS_GNOME_DB_DATA_ENTRY (de), FALSE);
+	g_return_val_if_fail (IS_GNOME_DB_DATA_ENTRY (de), FALSE);
 
 	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->expand_in_layout)
 		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->expand_in_layout) (de);
@@ -334,3 +334,20 @@ gnome_db_data_entry_expand_in_layout (GnomeDbDataEntry *de)
 	return FALSE;
 }
 
+/**
+ * gnome_db_data_entry_set_editable
+ * @de: a #GtkWidget object which implements the #GnomeDbDataEntry interface
+ * @editable:
+ *
+ * Set if @de can be modified or not by the user
+ */
+void
+gnome_db_data_entry_set_editable (GnomeDbDataEntry *de, gboolean editable)
+{
+	g_return_if_fail (IS_GNOME_DB_DATA_ENTRY (de));
+
+	if (GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_editable)
+		(GNOME_DB_DATA_ENTRY_GET_IFACE (de)->set_editable) (de, editable);
+	else
+		gtk_widget_set_sensitive (GTK_WIDGET (de), editable);
+}
