@@ -1,8 +1,9 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,19 +21,32 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <bonobo/bonobo-ui-main.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
+#ifdef HAVE_LIBGLADE
 #include <glade/glade-init.h>
+#endif
 #include <libgda/libgda.h>
+#ifdef BUILD_WITH_GNOME
 #include <libgnomeui/gnome-ui-init.h>
-#include <libgnomedb/libgnomedb.h>
-#include <bonobo/bonobo-i18n.h>
+#endif
+#include <gconf/gconf-client.h>
+#include <libgda/graph/gda-dict-reg-graphs.h>
+
+/* plugins list */
+GHashTable *gnome_db_plugins_hash = NULL; /* key = plugin name, value = GnomeDbPlugin structure pointer */
 
 extern void gnome_db_stock_init (void);
 
-/*
- * Public functions
+/**
+ * gnome_db_init
+ * @app_id:
+ * @version:
+ * @nargs:
+ * @args:
+ *
+ * Initialization of the libgnomedb library
  */
-
 void
 gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[])
 {
@@ -43,18 +57,32 @@ gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *arg
 		return;
 	}
 
-	bindtextdomain(GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	gda_init (app_id, version, nargs, args);
+
+#ifdef BUILD_WITH_GNOME
 	gnome_program_init (app_id, version, LIBGNOMEUI_MODULE, nargs, args,
 			    GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 
-	if (!bonobo_ui_is_initialized ())
-		bonobo_ui_init (app_id, version, &nargs, args);
+#else
+	gtk_init (&nargs, &args);
+#endif
 
+#ifdef HAVE_LIBGLADE
 	glade_init ();
+#endif
 	gnome_db_stock_init ();
+
+	/* init GConf */
+	if (!gconf_is_initialized ())
+		gconf_init (0, NULL, NULL);
+
+	/* make sure all the GdaDict object register GdaGraph */
+	gda_dict_class_always_register (gda_graphs_get_register);
+
+	initialized = TRUE;
 }
 
 typedef struct {
@@ -82,10 +110,6 @@ idle_cb (gpointer user_data)
  * @init_func: function to be called when everything has been initialized
  * @user_data: data to be passed to the init function
  *
- * Runs the GNOME-DB main loop, which is nothing more than the Bonobo UI main
- * loop, but with internally added stuff specific for applications using
- * libgda/libgnomedb.
- *
  * You can specify a function to be called after everything has been correctly
  * initialized (that is, for initializing your own stuff).
  */
@@ -102,7 +126,7 @@ gnome_db_main_run (GdaInitFunc init_func, gpointer user_data)
 		g_idle_add ((GSourceFunc) idle_cb, cb_data);
 	}
 
-	bonobo_ui_main ();
+	gtk_main();
 }
 
 /**
