@@ -1,6 +1,6 @@
 /* gnome-db-sql-console.c
  *
- * Copyright (C) 2005 Vivien Malerba
+ * Copyright (C) 2005 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,14 +21,9 @@
 #include <string.h>
 #include "gnome-db-sql-console.h"
 #include <gdk/gdkkeysyms.h>
-#include "gnome-db-query.h"
-#include "gnome-db-entity.h"
-#include "gnome-db-data-set.h"
-#include "gnome-db-server.h"
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
 #include "gnome-db-basic-form.h"
-#include "gnome-db-renderer.h"
-#include "gnome-db-parameter.h"
-
 
 static void gnome_db_sql_console_class_init (GnomeDbSqlConsoleClass * class);
 static void gnome_db_sql_console_init (GnomeDbSqlConsole * wid);
@@ -48,7 +43,7 @@ typedef struct {
 
 struct _GnomeDbSqlConsolePriv
 {
-	GnomeDbDict   *dict;
+	GdaDict       *dict;
 	GtkTextBuffer *buffer;
 
 	GList         *hist_items; /* list of HistItem elements */
@@ -103,22 +98,22 @@ gnome_db_sql_console_init (GnomeDbSqlConsole * wid)
 }
 
 static void gnome_db_sql_console_initialize (GnomeDbSqlConsole *console, const gchar *message);
-static void gnome_db_dict_weak_notify (GnomeDbSqlConsole *console, GnomeDbDict *dict);
+static void gda_dict_weak_notify (GnomeDbSqlConsole *console, GdaDict *dict);
 /**
  * gnome_db_sql_console_new
- * @dict: a #GnomeDbDict object
+ * @dict: a #GdaDict object
  *
  * Creates a new #GnomeDbSqlConsole widget 
  *
  * Returns: the new widget
  */
 GtkWidget *
-gnome_db_sql_console_new (GnomeDbDict *dict, const gchar *message)
+gnome_db_sql_console_new (GdaDict *dict, const gchar *message)
 {
 	GObject *obj;
 	GnomeDbSqlConsole *console;
 
-	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (!dict || GDA_IS_DICT (dict), NULL);
 
 	obj = g_object_new (GNOME_DB_TYPE_SQL_CONSOLE, NULL);
 	console = GNOME_DB_SQL_CONSOLE (obj);
@@ -126,7 +121,7 @@ gnome_db_sql_console_new (GnomeDbDict *dict, const gchar *message)
 	console->priv->dict = ASSERT_DICT (dict);
 	
 	g_object_weak_ref (G_OBJECT (console->priv->dict),
-			   (GWeakNotify) gnome_db_dict_weak_notify, console);
+			   (GWeakNotify) gda_dict_weak_notify, console);
 
 	gnome_db_sql_console_initialize (console, message);
 
@@ -135,9 +130,9 @@ gnome_db_sql_console_new (GnomeDbDict *dict, const gchar *message)
 
 
 static void
-gnome_db_dict_weak_notify (GnomeDbSqlConsole *console, GnomeDbDict *dict)
+gda_dict_weak_notify (GnomeDbSqlConsole *console, GdaDict *dict)
 {
-	/* Tell that we don't need to weak unref the GnomeDbDict */
+	/* Tell that we don't need to weak unref the GdaDict */
 	console->priv->dict = NULL;
 }
 
@@ -154,10 +149,10 @@ gnome_db_sql_console_dispose (GObject *object)
 		/* history */
 		gnome_db_sql_console_clear_history (console);
 		
-		/* Weak unref the GnomeDbDict is necessary */
+		/* Weak unref the GdaDict is necessary */
 		if (console->priv->dict)
 			g_object_weak_unref (G_OBJECT (console->priv->dict),
-					     (GWeakNotify) gnome_db_dict_weak_notify, console);
+					     (GWeakNotify) gda_dict_weak_notify, console);
 		
 		/* the private area itself */
 		g_free (console->priv);
@@ -404,22 +399,21 @@ view_event_cb (GtkWidget *widget, GdkEvent *event, GnomeDbSqlConsole *console)
 }
 
 static gint
-fill_context_in_dialog (GnomeDbSqlConsole *console, GnomeDbDataSet *context)
+fill_context_in_dialog (GnomeDbSqlConsole *console, GdaParameterList *context)
 {
 	GtkWidget *dlg;
 	GnomeDbBasicForm *sform;
 	GtkWidget *parent_window;
 	gint result;
 
-	if (! gnome_db_data_set_needs_user_input (context))
+	if (!context || gda_parameter_list_is_valid (context)) 
 		return GTK_RESPONSE_ACCEPT;
 	
 	parent_window = gtk_widget_get_toplevel (GTK_WIDGET (console));
 	if (! GTK_WIDGET_TOPLEVEL (parent_window))
 		parent_window = NULL;
 
-	dlg = gnome_db_basic_form_new_in_dialog (console->priv->dict, 
-						 context, GTK_WINDOW (parent_window),
+	dlg = gnome_db_basic_form_new_in_dialog (context, GTK_WINDOW (parent_window),
 						 _("Values to be filled"), 
 						 _("<big><b>Required values:</b></big>\n"
 						   "<small>The following values are required to "
@@ -434,31 +428,43 @@ fill_context_in_dialog (GnomeDbSqlConsole *console, GnomeDbDataSet *context)
 	return result;
 }
 
-static gchar *compute_events_as_string (GnomeDbServer *serv);
+static gchar *compute_events_as_string (GdaConnection *cnc);
 
 static void
 run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 {
+	GdaConnection *cnc;
 	GtkTextIter iter;
-	GnomeDbQuery *query;
-	GnomeDbDataSet *dset;
+	GdaQuery *query;
+	GdaParameterList *dset;
 	GError *error = NULL;
 	GdaDataModel *model;
 
 	gchar *str;
 	gboolean cmde_ok = FALSE;
 
+
+	cnc = gda_dict_get_connection (console->priv->dict);
+	if (!cnc) {
+		g_warning ("No connection associated to dictionary, can't run query");
+		return;
+	}
+	if (! gda_connection_is_opened (cnc)) {
+		g_warning ("Connection closed, can't run query");
+		return;
+	}
+
 	gtk_text_buffer_get_end_iter (console->priv->buffer, &iter);
 	
 	/* run query */
-	query = GNOME_DB_QUERY (gnome_db_query_new_from_sql (console->priv->dict, sql, NULL));
-	dset = gnome_db_entity_get_exec_dataset (GNOME_DB_ENTITY (query));
+	query = GDA_QUERY (gda_query_new_from_sql (console->priv->dict, sql, NULL));
+	dset = gda_query_get_parameters_boxed (query);
 	if (fill_context_in_dialog (console, dset) != GTK_RESPONSE_ACCEPT) 
 		str = g_strdup (_("Cancelled"));
 	else {
 		gchar *rsql;
 
-		if (dset->parameters) {
+		if (dset && dset->parameters) {
 			/* dump param's values */
 			GString *string;
 			GSList *list;
@@ -466,11 +472,11 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 			string = g_string_new ("\n");
 			list = dset->parameters;
 			while (list) {
-				const GdaValue *value;
-				value = gnome_db_parameter_get_value (GNOME_DB_PARAMETER (list->data));
-				str = gda_value_stringify (value);
+				const GValue *value;
+				value = gda_parameter_get_value (GDA_PARAMETER (list->data));
+				str = gda_value_stringify ((GValue *) value);
 				g_string_append_printf (string, "%s => %s\n", 
-							gnome_db_base_get_name (GNOME_DB_BASE (list->data)), str);
+							gda_object_get_name (GDA_OBJECT (list->data)), str);
 				g_free (str);
 				list = g_slist_next (list);
 			}
@@ -480,20 +486,21 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 		}
 
 		/* run query */
-		rsql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (query), dset, 0, &error);
+		rsql = gda_renderer_render_as_sql (GDA_RENDERER (query), dset, 0, &error);
 		if (rsql) {
-			GnomeDbServer *serv;
+			GdaCommand *cmde;
 
-			serv = gnome_db_dict_get_server (console->priv->dict);
-			model = gnome_db_server_do_query_as_data_model (serv, rsql, GNOME_DB_SERVER_QUERY_SQL, &error);
-			if (model && (gda_data_model_get_n_rows (model) > 0)) {
+			cmde = gda_command_new (rsql, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
+			model = gda_connection_execute_command (cnc, cmde, NULL, &error);
+			gda_command_free (cmde);
+			if (model && (model != GDA_CONNECTION_EXEC_FAILED) && (gda_data_model_get_n_rows (model) > 0)) {
 				gchar *str1, *str2;
 
 				cmde_ok = TRUE;
 				str = gda_data_model_dump_as_string (model);
 				g_object_unref (model);
 
-				str1 = compute_events_as_string (serv);
+				str1 = compute_events_as_string (cnc);
 				str2 = g_strconcat (str, str1, NULL);
 				g_free (str1);
 				g_free (str);
@@ -506,9 +513,10 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 						str = g_strdup (error->message);
 					else
 						str = g_strdup (_("Error: no details"));
+					g_error_free (error);
 				}
 				if (!str) {
-					str = compute_events_as_string (serv);
+					str = compute_events_as_string (cnc);
 					if (!str)
 						str = g_strdup (_("Ok."));
 					
@@ -531,17 +539,18 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 	gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n\n", 2, cmde_ok ? "result-ok" : "result-error", NULL);
 
 	g_free (str);
-	g_object_unref (dset);
+	if (dset)
+		g_object_unref (dset);
 	g_object_unref (query);
 }
 
 static gchar *
-compute_events_as_string (GnomeDbServer *serv)
+compute_events_as_string (GdaConnection *cnc)
 {
 	GList *events;
 	gchar *str = NULL;
 	
-	events = gda_connection_get_events (gnome_db_server_get_gda_connection (serv));
+	events = (GList *) gda_connection_get_events (cnc);
 	if (events) {
 		GString *string = NULL;
 		GdaConnectionEvent *event;
