@@ -1,6 +1,6 @@
 /* gnome-db-canvas-fkconstraint.c
  *
- * Copyright (C) 2004 - 2005 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,12 +20,12 @@
 
 #include <gtk/gtk.h>
 #include <math.h>
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
 #include "gnome-db-canvas.h"
 #include "gnome-db-canvas-fkconstraint.h"
 #include "gnome-db-canvas-entity.h"
 #include "gnome-db-canvas-text.h"
-#include <libgnomedb/gnome-db-field.h>
-#include <libgnomedb/gnome-db-constraint.h>
 #include "graph-utility.h"
 
 static void gnome_db_canvas_fkconstraint_class_init (GnomeDbCanvasFkconstraintClass * class);
@@ -33,14 +33,14 @@ static void gnome_db_canvas_fkconstraint_init       (GnomeDbCanvasFkconstraint *
 static void gnome_db_canvas_fkconstraint_dispose    (GObject   * object);
 static void gnome_db_canvas_fkconstraint_finalize   (GObject   * object);
 
-static void gnome_db_canvas_fkconstraint_set_property    (GObject              *object,
-						    guint                 param_id,
-						    const GValue         *value,
-						    GParamSpec           *pspec);
-static void gnome_db_canvas_fkconstraint_get_property    (GObject              *object,
-						    guint                 param_id,
-						    GValue               *value,
-						    GParamSpec           *pspec);
+static void gnome_db_canvas_fkconstraint_set_property    (GObject *object,
+						    guint param_id,
+						    const GValue *value,
+						    GParamSpec *pspec);
+static void gnome_db_canvas_fkconstraint_get_property    (GObject *object,
+						    guint param_id,
+						    GValue *value,
+						    GParamSpec *pspec);
 
 static void clean_items (GnomeDbCanvasFkconstraint *cc);
 static void create_items (GnomeDbCanvasFkconstraint *cc);
@@ -115,7 +115,7 @@ gnome_db_canvas_fkconstraint_init (GnomeDbCanvasFkconstraint *cc)
 
 
 static void entity_destroy_cb (GnomeDbCanvasEntity *entity, GnomeDbCanvasFkconstraint *cc);
-static void constraint_nullified_cb (GnomeDbConstraint *fkcons, GnomeDbCanvasFkconstraint *cc);
+static void constraint_destroyed_cb (GdaDictConstraint *fkcons, GnomeDbCanvasFkconstraint *cc);
 
 static void
 gnome_db_canvas_fkconstraint_dispose (GObject *object)
@@ -131,7 +131,7 @@ gnome_db_canvas_fkconstraint_dispose (GObject *object)
 		GSList *list = cc->priv->constraints;
 		while (list) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (list->data),
-							      G_CALLBACK (constraint_nullified_cb), cc);
+							      G_CALLBACK (constraint_destroyed_cb), cc);
 			list = g_slist_next (list);
 		}
 		g_slist_free (cc->priv->constraints);
@@ -144,7 +144,7 @@ gnome_db_canvas_fkconstraint_dispose (GObject *object)
 
 
 static void
-gnome_db_canvas_fkconstraint_finalize (GObject  *object)
+gnome_db_canvas_fkconstraint_finalize (GObject *object)
 {
 	GnomeDbCanvasFkconstraint *cc;
 	g_return_if_fail (object != NULL);
@@ -161,10 +161,10 @@ gnome_db_canvas_fkconstraint_finalize (GObject  *object)
 }
 
 static void 
-gnome_db_canvas_fkconstraint_set_property    (GObject              *object,
-					guint                 param_id,
-					const GValue         *value,
-					GParamSpec           *pspec)
+gnome_db_canvas_fkconstraint_set_property    (GObject *object,
+					guint param_id,
+					const GValue *value,
+					GParamSpec *pspec)
 {
 	GnomeDbCanvasFkconstraint *cc;
 
@@ -178,10 +178,10 @@ gnome_db_canvas_fkconstraint_set_property    (GObject              *object,
 }
 
 static void 
-gnome_db_canvas_fkconstraint_get_property    (GObject              *object,
-					guint                 param_id,
-					GValue               *value,
-					GParamSpec           *pspec)
+gnome_db_canvas_fkconstraint_get_property    (GObject *object,
+					guint param_id,
+					GValue *value,
+					GParamSpec *pspec)
 {
 	GnomeDbCanvasFkconstraint *cc;
 
@@ -195,12 +195,12 @@ gnome_db_canvas_fkconstraint_get_property    (GObject              *object,
 }
 
 static void
-constraint_nullified_cb (GnomeDbConstraint *fkcons, GnomeDbCanvasFkconstraint *cc)
+constraint_destroyed_cb (GdaDictConstraint *fkcons, GnomeDbCanvasFkconstraint *cc)
 {
 	g_assert (g_slist_find (cc->priv->constraints, fkcons));
 	cc->priv->constraints = g_slist_remove (cc->priv->constraints, fkcons);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (fkcons),
-					      G_CALLBACK (constraint_nullified_cb), cc);
+					      G_CALLBACK (constraint_destroyed_cb), cc);
 	
 	/* destroy itself if there are no more constraint left in the end */
 	if (!cc->priv->constraints)
@@ -260,8 +260,8 @@ create_items (GnomeDbCanvasFkconstraint *cc)
 {
 	GnomeCanvasItem *item;
 	GSList *fklist = cc->priv->constraints, *list, *canvas_shapes, *list2, *list3;
-	GnomeDbConstraint *fkcons;
-	GnomeDbTable *table;
+	GdaDictConstraint *fkcons;
+	GdaDictTable *table;
 	GnomeDbCanvasItem *entity_item;
 	GnomeDbCanvas *canvas = gnome_db_canvas_item_get_canvas (GNOME_DB_CANVAS_ITEM (cc));
 	gboolean user_constraint;
@@ -270,10 +270,10 @@ create_items (GnomeDbCanvasFkconstraint *cc)
 		return;
 
 	/* Analyse FK constraint */
-	fkcons = GNOME_DB_CONSTRAINT (fklist->data);
+	fkcons = GDA_DICT_CONSTRAINT (fklist->data);
 	item = GNOME_CANVAS_ITEM (cc);
-	table = gnome_db_constraint_get_table (fkcons);
-	entity_item = gnome_db_canvas_get_item_for_object (canvas, GNOME_DB_BASE (table));
+	table = gda_dict_constraint_get_table (fkcons);
+	entity_item = gnome_db_canvas_get_item_for_object (canvas, GDA_OBJECT (table));
 	g_return_if_fail (entity_item);
 	cc->priv->fk_entity_item = GNOME_DB_CANVAS_ENTITY (entity_item);
 	g_signal_connect (G_OBJECT (entity_item), "moving",
@@ -285,8 +285,8 @@ create_items (GnomeDbCanvasFkconstraint *cc)
 	g_signal_connect (G_OBJECT (entity_item), "destroy",
 			  G_CALLBACK (entity_destroy_cb), cc);
 
-	table = gnome_db_constraint_fkey_get_ref_table (fkcons);
-	entity_item = gnome_db_canvas_get_item_for_object (canvas, GNOME_DB_BASE (table));
+	table = gda_dict_constraint_fkey_get_ref_table (fkcons);
+	entity_item = gnome_db_canvas_get_item_for_object (canvas, GDA_OBJECT (table));
 	g_return_if_fail (entity_item);
 	cc->priv->ref_pk_entity_item = GNOME_DB_CANVAS_ENTITY (entity_item);
 	g_signal_connect (G_OBJECT (entity_item), "moving",
@@ -308,7 +308,7 @@ create_items (GnomeDbCanvasFkconstraint *cc)
 	list = fklist;
 	while (list && list2) {
 		gchar *color = "black";
-		fkcons = GNOME_DB_CONSTRAINT (list->data);
+		fkcons = GDA_DICT_CONSTRAINT (list->data);
 		g_object_get (G_OBJECT (fkcons), "user_constraint", &user_constraint, NULL);
 		if (user_constraint)
 			color = "#B2B2B2";
@@ -347,7 +347,7 @@ static void popup_delete_cb (GtkMenuItem *mitem, GnomeDbCanvasFkconstraint *cc);
 static gboolean
 single_item_event_cb (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasFkconstraint *cc)
 {
-	GnomeDbConstraint *fkcons = g_object_get_data (G_OBJECT (ci), "fkcons");
+	GdaDictConstraint *fkcons = g_object_get_data (G_OBJECT (ci), "fkcons");
 	gboolean highlight = FALSE, is_user_constraint = FALSE;
 	GtkWidget *menu, *entry;
 	gboolean done = FALSE;
@@ -357,17 +357,17 @@ single_item_event_cb (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasFkconst
 	case GDK_ENTER_NOTIFY:
 		highlight = TRUE;
 	case GDK_LEAVE_NOTIFY:
-		pairs = gnome_db_constraint_fkey_get_fields (fkcons);
+		pairs = gda_dict_constraint_fkey_get_fields (fkcons);
 		list = pairs;
 		while (list) {
-			GnomeDbConstraintFkeyPair *pair = GNOME_DB_CONSTRAINT_FK_PAIR (list->data);
+			GdaDictConstraintFkeyPair *pair = GDA_DICT_CONSTRAINT_FK_PAIR (list->data);
 			GnomeDbCanvasField *field;
 			
 			field = gnome_db_canvas_entity_get_field_item (cc->priv->fk_entity_item, 
-								 GNOME_DB_FIELD (pair->fkey));
+								 GDA_ENTITY_FIELD (pair->fkey));
 			gnome_db_canvas_text_set_highlight (GNOME_DB_CANVAS_TEXT (field), highlight);
 			field = gnome_db_canvas_entity_get_field_item (cc->priv->ref_pk_entity_item, 
-								 GNOME_DB_FIELD (pair->ref_pkey));
+								 GDA_ENTITY_FIELD (pair->ref_pkey));
 			gnome_db_canvas_text_set_highlight (GNOME_DB_CANVAS_TEXT (field), highlight);
 			
 			g_free (pair);
@@ -400,12 +400,12 @@ single_item_event_cb (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasFkconst
 static void
 popup_delete_cb (GtkMenuItem *mitem, GnomeDbCanvasFkconstraint *cc)
 {
-	GnomeDbConstraint *fkcons = g_object_get_data (G_OBJECT (mitem), "fkcons");
+	GdaDictConstraint *fkcons = g_object_get_data (G_OBJECT (mitem), "fkcons");
 	gboolean is_user_constraint;
 
 	g_object_get (G_OBJECT (fkcons), "user_constraint", &is_user_constraint, NULL);
 	if (is_user_constraint)
-		gnome_db_base_nullify (GNOME_DB_BASE (fkcons));
+		gda_object_destroy (GDA_OBJECT (fkcons));
 }
 
 static void
@@ -424,12 +424,12 @@ entity_item_moved_cb (GnomeCanvasItem *entity, GnomeDbCanvasFkconstraint *cc)
  * Add @fkcons to the list of displayed constraints
  */
 void
-gnome_db_canvas_fkconstraint_add_constraint (GnomeDbCanvasFkconstraint *cc, GnomeDbConstraint *fkcons)
+gnome_db_canvas_fkconstraint_add_constraint (GnomeDbCanvasFkconstraint *cc, GdaDictConstraint *fkcons)
 {
 	g_return_if_fail (cc && IS_GNOME_DB_CANVAS_FKCONSTRAINT (cc));
 	g_return_if_fail (cc->priv);
-	g_return_if_fail (fkcons && IS_GNOME_DB_CONSTRAINT (fkcons));
-	g_return_if_fail (gnome_db_constraint_get_constraint_type (GNOME_DB_CONSTRAINT (fkcons)) == 
+	g_return_if_fail (fkcons && GDA_IS_DICT_CONSTRAINT (fkcons));
+	g_return_if_fail (gda_dict_constraint_get_constraint_type (GDA_DICT_CONSTRAINT (fkcons)) == 
 			  CONSTRAINT_FOREIGN_KEY);
 
 	if (g_slist_find (cc->priv->constraints, fkcons))
@@ -442,7 +442,7 @@ gnome_db_canvas_fkconstraint_add_constraint (GnomeDbCanvasFkconstraint *cc, Gnom
 	}
 
 	cc->priv->constraints = g_slist_append (cc->priv->constraints, fkcons);
-	gnome_db_base_connect_nullify (fkcons, G_CALLBACK (constraint_nullified_cb), cc);
+	gda_object_connect_destroy (fkcons, G_CALLBACK (constraint_destroyed_cb), cc);
 
 	clean_items (cc);
 	create_items (cc);
